/**
 * Copyright (c) 2016-2018 CPU and Fundamental Software Research Center, CAS
 * 
 * This software is published by the license of CPU-OS License，you can use and 
 * distibuted this software under this License. See CPU-OS Liense for more detail.
 *
 * You should have receive a copy of CPU-OS License. If not, please contact us 
 * by email <support_os@cpu-os.ac.cn>  
 * 
**/

#ifndef __CDOS_AUDIT_QUERY_COND_H__
#define __CDOS_AUDIT_QUERY_COND_H__

#include <core/cdos-def.h>
#include <time.h>
#include <audit/cdos-audit-query-config.h>
#include <audit/cdos-audit-types.h>

CDOS_BEGIN_DECLS

typedef enum {
    DTType_CUSTOM = 0,
    DTType_TODAY,
    DTType_THISWEEK,
    DTType_THISMONTH,
    DTType_THISYEAR,
    DTType_ALL
} CdosAuQueryCondDatetimeType;

typedef struct _CdosAuQueryCond CdosAuQueryCond;

CDOS_EXPORT CdosAuQueryCond* cdos_au_query_cond_create_with_cmd(const char* cmdFullPath);
CDOS_EXPORT CdosAuQueryCond* cdos_au_query_cond_create_with_config(const CdosAuQueryConfig* config);

CDOS_EXPORT void cdos_au_query_cond_add_type(CdosAuQueryCond* self,
                                             CdosAuQueryType type);

CDOS_EXPORT void cdos_au_query_cond_remove_type(CdosAuQueryCond* self,
                                                CdosAuQueryType type);

CDOS_EXPORT unsigned int cdos_au_query_cond_get_type(const CdosAuQueryCond* self);


CDOS_EXPORT void cdos_au_query_cond_set_datetime_and_type(CdosAuQueryCond* self,
                                                          CdosAuQueryCondDatetimeType type,
                                                          const struct tm* starttm,
                                                          const struct tm* endtm);

CDOS_EXPORT void cdos_au_query_cond_set_exec_user(CdosAuQueryCond* self,
                                                  const char* execUserName);

CDOS_EXPORT void cdos_au_query_cond_set_exec_exitcode(CdosAuQueryCond* self,
                                                      int code);

CDOS_EXPORT CdosAuQueryCondDatetimeType cdos_au_query_cond_get_datetime_and_type(const CdosAuQueryCond* self,
                                                                                 struct tm** starttm,
                                                                                 struct tm** endtm);

CDOS_EXPORT const char* cdos_au_query_cond_get_exec_user(const CdosAuQueryCond* self);

CDOS_EXPORT int cdos_au_query_cond_get_exec_exitcode(const CdosAuQueryCond* self);

CDOS_EXPORT const char* cdos_au_query_cond_get_full_cmd_path(const CdosAuQueryCond* self);

CDOS_EXPORT const char* cdos_au_query_cond_get_input_log_path(const CdosAuQueryCond* self);

CDOS_EXPORT void cdos_au_query_cond_destroy(CdosAuQueryCond** self);

CDOS_END_DECLS

#endif // __CDOS_AUDIT_QUERY_COND_H__